import React from 'react';
import { StyleSheet, View, Platform } from 'react-native';
import Slider from 'react-native-slider';
import Gradient from './Gradient';

const GradientSlider = ({
  step,
  maximumValue,
  gradientSteps,
  value,
  getColor,
  style,
  onValueChange,
  thumbTintColor
}) => {
  return (
    <View style={[styles.container, style]}>
      <Gradient
        style={styles.gradient}
        gradientSteps={gradientSteps}
        getColor={getColor}
        maximumValue={maximumValue}
      />
      <Slider
        value={value}
        step={step}
        animateTransitions
        animationType="spring"
        thumbTouchSize={{ width: 48, height: 48 }}
        maximumValue={maximumValue}
        onValueChange={onValueChange}
        minimumTrackTintColor="transparent"
        maximumTrackTintColor="transparent"
        thumbStyle={[styles.thumb, { backgroundColor: thumbTintColor }]}
      />
    </View>
  );
};

export default GradientSlider;

const styles = StyleSheet.create({
  container: {
    flexDirection: 'column',
    justifyContent: 'center',
    alignItems: 'stretch',
    height: 32
  },
  gradient: {
    position: 'absolute', //TODO Review
    minHeight: 6
  },
  thumb: {
    width: 24,
    height: 24,
    borderRadius: 24 / 2,
    shadowColor: 'black',
    shadowOffset: { width: 0, height: 2 },
    shadowRadius: 4,
    shadowOpacity: 0.15
  }
});
